@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,12 +19,10 @@
 
 #include <libexplain/ac/assert.h>
 #include <libexplain/ac/ctype.h>
-#include <libexplain/ac/pwd.h>
 #include <libexplain/ac/stdio.h>
 #include <libexplain/ac/stdlib.h>
 #include <libexplain/ac/string.h>
 #include <libexplain/ac/sys/stat.h>
-#include <libexplain/ac/time.h>
 #include <libexplain/ac/unistd.h>
 
 #include <libexplain/errno_info.h>
@@ -33,13 +31,16 @@
 #include <libexplain/malloc.h>
 #include <libexplain/sizeof.h>
 #include <libexplain/strdup.h>
+#include <libexplain/string_list.h>
+#include <libexplain/strndup.h>
 #include <libexplain/system.h>
 
 #include <codegen/aegis.h>
 #include <codegen/boolean.h>
-#include <codegen/generate.h>
-#include <codegen/header.h>
 #include <codegen/elastic_buffer.h>
+#include <codegen/generate.h>
+#include <codegen/get_user_name.h>
+#include <codegen/header.h>
 #include <codegen/wrapper.h>
 
 
@@ -555,16 +556,6 @@ groff_message(FILE *fp)
 static void
 groff_footer(FILE *fp)
 {
-    time_t          now;
-    struct tm       *tmp;
-    struct passwd   *pw;
-    char            *cp;
-    char            user_name[100];
-
-    time(&now);
-    tmp = localtime(&now);
-    pw = getpwuid(getuid());
-
     fprintf(fp, ".\\\" ----------------------------------------------------\n");
     fprintf(fp, ".SH COPYRIGHT\n");
     fprintf(fp, ".so etc/version.so\n");
@@ -572,17 +563,7 @@ groff_footer(FILE *fp)
     fprintf(fp, ".if t .ds C) \\(co\n");
     fprintf(fp, "libexplain version \\*(v)\n");
     fprintf(fp, ".br\n");
-    snprintf(user_name, sizeof(user_name), "%s", (pw ? pw->pw_gecos : "you"));
-    cp = user_name + strlen(user_name);
-    while (cp > user_name && cp[-1] == ',')
-        *--cp = '\0';
-    fprintf
-    (
-        fp,
-        "Copyright \\*(C) %d %s\n",
-        tmp->tm_year + 1900,
-        user_name
-    );
+    fprintf(fp, "Copyright \\*(C) %d %s\n", get_year(), get_user_name());
 }
 
 
@@ -654,6 +635,7 @@ static int      ret_ptr;
 static int      use_return_value;
 static int      or_die_warn_unused;
 static int      reset_errno;
+static const char *system_include;
 
 
 static void
@@ -751,6 +733,12 @@ libexplain_fubar_h(node_t *declaration)
     fprintf(fp, "  */\n");
     fprintf(fp, "\n");
     fprintf(fp, "#include <libexplain/warn_unused_result.h>\n");
+    if (system_include)
+    {
+        fprintf(fp, "#include <libexplain/large_file_support.h>\n");
+        fprintf(fp, "\n");
+        fprintf(fp, "#include <%s>\n", system_include);
+    }
     fprintf(fp, "\n");
     fprintf(fp, "#ifdef __cplusplus\n");
     fprintf(fp, "extern \"C\" {\n");
@@ -1207,8 +1195,10 @@ man_man3_explain_fubar_3(void)
     fprintf(fp, ".SH NAME\n");
     fprintf(fp, "explain_%s \\- explain \\f[I]%s\\fP(%d) errors\n",
         function_name, function_name, section);
+    fprintf(fp, ".if require_index \\{\n");
     fprintf(fp, ".XX \"explain_%s(3)\" \"explain \\f[I]%s\\fP(%d) errors\"\n",
         function_name, function_name, section);
+    fprintf(fp, ".\\}\n");
     fprintf(fp, ".SH SYNOPSIS\n");
     fprintf(fp, "#include <libexplain/%s.h>\n", function_name);
     fprintf(fp, ".sp 0.3\n");
@@ -1533,8 +1523,10 @@ man_man3_explain_fubar_or_die_3(node_t *declaration)
     fprintf(fp, ".SH NAME\n");
     fprintf(fp, "explain_%s_or_die \\- ", function_name);
     fprintf(fp, "%s and report errors\n", synopsis);
+    fprintf(fp, ".if require_index \\{\n");
     fprintf(fp, ".XX \"explain_%s_or_die(3)\" \\\n", function_name);
     fprintf(fp, "    \"%s and report errors\"\n", synopsis);
+    fprintf(fp, ".\\}\n");
     fprintf(fp, ".SH SYNOPSIS\n");
     fprintf(fp, "#include <libexplain/%s.h>\n", function_name);
     fprintf(fp, ".sp 0.3\n");
@@ -1666,7 +1658,7 @@ libexplain_fubar_or_die_c(node_t *declaration)
 {
     FILE            *fp;
     elastic_buffer_t sb;
-    node_t          *np;
+    size_t          j;
     char            filename[1000];
 
     ret_ptr = function_returns_pointer(declaration);
@@ -1679,16 +1671,64 @@ libexplain_fubar_or_die_c(node_t *declaration)
     fp = explain_fopen_or_die(filename, "w");
     generate_lgpl_header(fp);
     fprintf(fp, "\n");
-    fprintf(fp, "#include <libexplain/ac/stdlib.h>\n");
+    {
+        explain_string_list_t incls;
+
+        explain_string_list_constructor(&incls);
+        explain_string_list_append
+        (
+            &incls,
+            "#include <libexplain/ac/errno.h>\n"
+        );
+        if (system_include && 0 != strcmp(system_include, "errno.h"))
+        {
+            char            line[256];
+
+            snprintf
+            (
+                line,
+                sizeof(line),
+                "#include <libexplain/ac/%s>\n",
+                system_include
+            );
+            explain_string_list_append(&incls, line);
+        }
+        explain_string_list_sort(&incls);
+        for (j = 0; j < incls.length; ++j)
+            fputs(incls.string[j], fp);
+        explain_string_list_destructor(&incls);
+    }
     fprintf(fp, "\n");
-    fprintf(fp, "#include <libexplain/%s.h>\n", function_name);
+    {
+        explain_string_list_t incls;
+        char            line[256];
+
+        explain_string_list_constructor(&incls);
+        explain_string_list_append(&incls, "#include <libexplain/option.h>\n");
+        explain_string_list_append(&incls, "#include <libexplain/output.h>\n");
+        snprintf
+        (
+            line,
+            sizeof(line),
+            "#include <libexplain/%s.h>\n",
+            function_name);
+        explain_string_list_append(&incls, line);
+        explain_string_list_sort(&incls);
+        for (j = 0; j < incls.length; ++j)
+            fputs(incls.string[j], fp);
+        explain_string_list_destructor(&incls);
+    }
     fprintf(fp, "\n");
     fprintf(fp, "\n");
 
     elastic_buffer_rewind(&sb);
-    np = node_synth_or_die(declaration, use_return_value);
-    node_print_sb(np, &sb, node_print_style_function);
-    node_free(np);
+    {
+        node_t          *np;
+
+        np = node_synth_or_die(declaration, use_return_value);
+        node_print_sb(np, &sb, node_print_style_function);
+        node_free(np);
+    }
     wrapper_hang(fp, "", elastic_buffer_get(&sb));
     fprintf(fp, "{\n");
     if (ret_int && !use_return_value)
@@ -1743,38 +1783,12 @@ libexplain_fubar_or_die_c(node_t *declaration)
         fprintf(fp, ")\n");
     }
     fprintf(fp, "    {\n");
-    fprintf(fp, "        exit(EXIT_FAILURE);\n");
+    fprintf(fp, "        explain_output_exit_failure();\n");
     fprintf(fp, "    }\n");
     if (use_return_value)
         fprintf(fp, "    return result;\n");
     fprintf(fp, "}\n");
-    vim_line(fp, "\n\n/*", "*/");
-    explain_fclose_or_die(fp);
-    elastic_buffer_destructor(&sb);
-}
 
-
-static void
-libexplain_fubar_on_error_c(node_t *declaration)
-{
-    FILE            *fp;
-    elastic_buffer_t sb;
-    char            filename[1000];
-
-    snprintf(filename, sizeof(filename), "libexplain/%s_on_error.c",
-        function_name);
-    if (!selected(filename))
-        return;
-    elastic_buffer_constructor(&sb);
-    aegis_new_file(filename);
-    fp = explain_fopen_or_die(filename, "w");
-    generate_lgpl_header(fp);
-    fprintf(fp, "\n");
-    fprintf(fp, "#include <libexplain/ac/stdio.h>\n");
-    fprintf(fp, "\n");
-    fprintf(fp, "#include <libexplain/%s.h>\n", function_name);
-    fprintf(fp, "#include <libexplain/option.h>\n");
-    fprintf(fp, "#include <libexplain/wrap_and_print.h>\n");
     fprintf(fp, "\n");
     fprintf(fp, "\n");
     elastic_buffer_rewind(&sb);
@@ -1793,9 +1807,14 @@ libexplain_fubar_on_error_c(node_t *declaration)
         elastic_buffer_putc(&sb, ';');
     }
     wrapper_hang(fp, "    ", elastic_buffer_get(&sb));
+    if (reset_errno)
+        fprintf(fp, "    int             hold_errno;\n");
     fprintf(fp, "\n");
     if (reset_errno)
-        fprintf(stderr, "    errno = 0;\n");
+    {
+        fprintf(fp, "    hold_errno = errno;\n");
+        fprintf(fp, "    errno = 0;\n");
+    }
     elastic_buffer_rewind(&sb);
     elastic_buffer_puts(&sb, "result = ");
     elastic_buffer_puts(&sb, function_name);
@@ -1812,15 +1831,22 @@ libexplain_fubar_on_error_c(node_t *declaration)
         fprintf(fp, " && errno != 0");
     fprintf(fp, ")\n");
     fprintf(fp, "    {\n");
+    if (!reset_errno)
+        fprintf(fp, "        int             hold_errno;\n\n");
+    fprintf(fp, "        hold_errno = errno;\n");
     fprintf(fp, "        explain_program_name_assemble_internal(1);\n");
     elastic_buffer_rewind(&sb);
-    elastic_buffer_puts(&sb, "explain_wrap_and_print(stderr, explain_");
+    elastic_buffer_puts(&sb, "explain_output_message(explain_errno_");
     elastic_buffer_puts(&sb, function_name);
-    elastic_buffer_putc(&sb, '(');
+    elastic_buffer_puts(&sb, "(hold_errno, ");
     node_print_sb(call_args, &sb, node_print_style_normal);
     elastic_buffer_puts(&sb, "));");
     wrapper_hang(fp, "        ", elastic_buffer_get(&sb));
+    if (!reset_errno)
+        fprintf(fp, "        errno = hold_errno;\n");
     fprintf(fp, "    }\n");
+    if (reset_errno)
+        fprintf(fp, "    errno = hold_errno;\n");
     fprintf(fp, "    return result;\n");
     fprintf(fp, "}\n");
     vim_line(fp, "\n\n/*", "*/");
@@ -1834,6 +1860,7 @@ libexplain_fubar_c(void)
 {
     FILE            *fp;
     elastic_buffer_t sb;
+    size_t          j;
     char            filename[1000];
 
     snprintf(filename, sizeof(filename), "libexplain/%s.c", function_name);
@@ -1844,9 +1871,65 @@ libexplain_fubar_c(void)
     fp = explain_fopen_or_die(filename, "w");
     generate_lgpl_header(fp);
     fprintf(fp, "\n");
-    fprintf(fp, "#include <libexplain/ac/errno.h>\n");
+    {
+        explain_string_list_t incls;
+
+        explain_string_list_constructor(&incls);
+        explain_string_list_append
+        (
+            &incls,
+            "#include <libexplain/ac/errno.h>\n"
+        );
+        if (system_include && 0 != strcmp(system_include, "errno.h"))
+        {
+            char            line[256];
+
+            snprintf
+            (
+                line,
+                sizeof(line),
+                "#include <libexplain/ac/%s>\n",
+                system_include
+            );
+            explain_string_list_append(&incls, line);
+        }
+        explain_string_list_sort(&incls);
+        for (j = 0; j < incls.length; ++j)
+            fputs(incls.string[j], fp);
+        explain_string_list_destructor(&incls);
+    }
     fprintf(fp, "\n");
-    fprintf(fp, "#include <libexplain/%s.h>\n", function_name);
+    {
+        explain_string_list_t incls;
+        char            line[256];
+
+        explain_string_list_constructor(&incls);
+        explain_string_list_append
+        (
+            &incls,
+            "#include <libexplain/common_message_buffer.h>\n"
+        );
+        snprintf
+        (
+            line,
+            sizeof(line),
+            "#include <libexplain/buffer/errno/%s.h>\n",
+            function_name
+        );
+        explain_string_list_append(&incls, line);
+        snprintf
+        (
+            line,
+            sizeof(line),
+            "#include <libexplain/%s.h>\n",
+            function_name
+        );
+        explain_string_list_append(&incls, line);
+        explain_string_list_sort(&incls);
+        for (j = 0; j < incls.length; ++j)
+            fputs(incls.string[j], fp);
+        explain_string_list_destructor(&incls);
+    }
     fprintf(fp, "\n");
     fprintf(fp, "\n");
     fprintf(fp, "const char *\n");
@@ -1866,30 +1949,7 @@ libexplain_fubar_c(void)
     elastic_buffer_puts(&sb, ");");
     wrapper_hang(fp, "    ", elastic_buffer_get(&sb));
     fprintf(fp, "}\n");
-    vim_line(fp, "\n\n/*", "*/");
-    explain_fclose_or_die(fp);
-    elastic_buffer_destructor(&sb);
-}
 
-
-static void
-libexplain_errno_fubar_c(void)
-{
-    FILE            *fp;
-    elastic_buffer_t sb;
-    char            filename[1000];
-
-    snprintf(filename, sizeof(filename), "libexplain/errno/%s.c",
-        function_name);
-    if (!selected(filename))
-        return;
-    elastic_buffer_constructor(&sb);
-    aegis_new_file(filename);
-    fp = explain_fopen_or_die(filename, "w");
-    generate_lgpl_header(fp);
-    fprintf(fp, "\n");
-    fprintf(fp, "#include <libexplain/common_message_buffer.h>\n");
-    fprintf(fp, "#include <libexplain/%s.h>\n", function_name);
     fprintf(fp, "\n");
     fprintf(fp, "\n");
     fprintf(fp, "const char *\n");
@@ -1911,31 +1971,7 @@ libexplain_errno_fubar_c(void)
     wrapper_hang(fp, "    ", elastic_buffer_get(&sb));
     fprintf(fp, "    return explain_common_message_buffer;\n");
     fprintf(fp, "}\n");
-    vim_line(fp, "\n\n/*", "*/");
-    explain_fclose_or_die(fp);
-    elastic_buffer_destructor(&sb);
-}
 
-
-static void
-libexplain_message_fubar_c(void)
-{
-    FILE            *fp;
-    elastic_buffer_t sb;
-    char            filename[1000];
-
-    snprintf(filename, sizeof(filename), "libexplain/message/%s.c",
-        function_name);
-    if (!selected(filename))
-        return;
-    elastic_buffer_constructor(&sb);
-    aegis_new_file(filename);
-    fp = explain_fopen_or_die(filename, "w");
-    generate_lgpl_header(fp);
-    fprintf(fp, "\n");
-    fprintf(fp, "#include <libexplain/ac/errno.h>\n");
-    fprintf(fp, "\n");
-    fprintf(fp, "#include <libexplain/%s.h>\n", function_name);
     fprintf(fp, "\n");
     fprintf(fp, "\n");
     fprintf(fp, "void\n");
@@ -1955,30 +1991,7 @@ libexplain_message_fubar_c(void)
     elastic_buffer_puts(&sb, ");");
     wrapper_hang(fp, "    ", elastic_buffer_get(&sb));
     fprintf(fp, "}\n");
-    vim_line(fp, "\n\n/*", "*/");
-    explain_fclose_or_die(fp);
-    elastic_buffer_destructor(&sb);
-}
 
-
-static void
-libexplain_message_errno_fubar_c(void)
-{
-    FILE            *fp;
-    elastic_buffer_t sb;
-    char            filename[1000];
-
-    snprintf(filename, sizeof(filename), "libexplain/message/errno/%s.c",
-        function_name);
-    if (!selected(filename))
-        return;
-    elastic_buffer_constructor(&sb);
-    aegis_new_file(filename);
-    fp = explain_fopen_or_die(filename, "w");
-    generate_lgpl_header(fp);
-    fprintf(fp, "\n");
-    fprintf(fp, "#include <libexplain/buffer/errno/%s.h>\n", function_name);
-    fprintf(fp, "#include <libexplain/%s.h>\n", function_name);
     fprintf(fp, "\n");
     fprintf(fp, "\n");
     fprintf(fp, "void\n");
@@ -2028,6 +2041,11 @@ libexplain_buffer_errno_fubar_h(void)
     fprintf(fp, "#ifndef %s\n", filename);
     fprintf(fp, "#define %s\n", filename);
     fprintf(fp, "\n");
+    if (system_include)
+    {
+        fprintf(fp, "#include <libexplain/ac/%s>\n", system_include);
+        fprintf(fp, "\n");
+    }
     fprintf(fp, "#include <libexplain/string_buffer.h>\n");
 
     /*
@@ -2169,14 +2187,47 @@ libexplain_buffer_errno_fubar_c(void)
     fprintf(fp, "\n");
     fprintf(fp, "#include <libexplain/ac/errno.h>\n");
     fprintf(fp, "\n");
-    for (j = 0; j < error_cases->child[0]->nchild; ++j)
     {
-        const char *lc = error_cases->child[1]->child[j]->literal;
-        fprintf(fp, "#include <libexplain/buffer/%s.h>\n", lc);
+        explain_string_list_t incls;
+        char            line[256];
+
+        explain_string_list_constructor(&incls);
+        for (j = 0; j < error_cases->child[0]->nchild; ++j)
+        {
+            const char *lc = error_cases->child[1]->child[j]->literal;
+            snprintf
+            (
+                line,
+                sizeof(line),
+                "#include <libexplain/buffer/%s.h>\n",
+                lc
+            );
+            explain_string_list_append(&incls, line);
+        }
+        explain_string_list_append
+        (
+            &incls,
+            "#include <libexplain/buffer/errno/generic.h>\n"
+        );
+        snprintf
+        (
+            line,
+            sizeof(line),
+            "#include <libexplain/buffer/errno/%s.h>\n",
+            function_name
+        );
+        explain_string_list_append(&incls, line);
+        explain_string_list_append
+        (
+            &incls,
+            "#include <libexplain/explanation.h>\n"
+        );
+
+        explain_string_list_sort(&incls);
+        for (j = 0; j < incls.length; ++j)
+            fputs(incls.string[j], fp);
+        explain_string_list_destructor(&incls);
     }
-    fprintf(fp, "#include <libexplain/buffer/errno/generic.h>\n");
-    fprintf(fp, "#include <libexplain/buffer/errno/%s.h>\n", function_name);
-    fprintf(fp, "#include <libexplain/explanation.h>\n");
     fprintf(fp, "\n");
     fprintf(fp, "\n");
     fprintf(fp, "static void\n");
@@ -2715,6 +2766,53 @@ man_man1_explain_1(void)
 }
 
 
+static const char *
+try_to_guess_include(const char *function)
+{
+    char            *result;
+    FILE            *fp;
+    char            command[200];
+
+    result = 0;
+    snprintf
+    (
+        command,
+        sizeof(command),
+        "find /usr/include -name '*.h' | xargs grep -l '\\<%s *('",
+        function
+    );
+    fp = popen(command, "r");
+    if (fp)
+    {
+        for (;;)
+        {
+            char            *name;
+            size_t          len;
+            char            line[1000];
+
+            if (!fgets(line, sizeof(line), fp))
+            break;
+            len = strlen(line);
+            while (len > 0 && isspace((unsigned char)line[len - 1]))
+                line[--len] = '\0';
+            assert(memcmp(line, "/usr/include/", 13) == 0);
+            name = line + 13;
+            if (!result)
+            {
+                result = strdup(name);
+            }
+            else if (strlen(result) > strlen(name))
+            {
+                free(result);
+                result = strdup(name);
+            }
+        }
+        pclose(fp);
+    }
+    return result;
+}
+
+
 void
 generate(node_t *declaration, catalogue_t *cat)
 {
@@ -2734,7 +2832,12 @@ generate(node_t *declaration, catalogue_t *cat)
     assert(node_is(decl, "declarator"));
 
     function_name = find_function_name(declaration);
-    section = try_to_guess_section(function_name);
+    section = catalogue_get_int(cat, "section", 0);
+    if (section < 2)
+    {
+        section = try_to_guess_section(function_name);
+        catalogue_set_int(cat, "Section", section);
+    }
 
     synopsis = catalogue_get(cat, "Synopsis");
     if (!synopsis)
@@ -2743,6 +2846,25 @@ generate(node_t *declaration, catalogue_t *cat)
         catalogue_set(cat, "Synopsis", synopsis);
     }
 
+    system_include = catalogue_get(cat, "Include");
+    if (!system_include)
+    {
+        system_include = try_to_guess_include(function_name);
+        if (system_include)
+            catalogue_set(cat, "Include", system_include);
+    }
+
+    if (system_include && system_include[0] == '<')
+    {
+        size_t len = strlen(system_include);
+        if (system_include[len - 1] == '>')
+        {
+            system_include =
+                explain_strndup_or_die(system_include + 1, len - 2);
+            catalogue_set(cat, "Include", system_include);
+        }
+    }
+
     args = find_argument_list(decl);
 
     call_args = synth_call_args(args);
@@ -2750,23 +2872,8 @@ generate(node_t *declaration, catalogue_t *cat)
     ret_ptr = function_returns_pointer(declaration);
     ret_int = function_returns_int(declaration);
 
-    {
-        const char *uret = catalogue_get(cat, "Use-Return-Value");
-        if (uret)
-        {
-            use_return_value = string_to_boolean(uret);
-        }
-        else
-        {
-            use_return_value = ret_ptr || !ret_int;
-            catalogue_set
-            (
-                cat,
-                "Use-Return-Value",
-                boolean_to_string(use_return_value)
-            );
-        }
-    }
+    use_return_value =
+        catalogue_get_bool(cat, "Use-Return-Value", ret_ptr || !ret_int);
 
     or_die_warn_unused =
         catalogue_get_bool(cat, "Or-Die-Warn-Unused", use_return_value);
@@ -2777,13 +2884,9 @@ generate(node_t *declaration, catalogue_t *cat)
     explain_syscall_fubar_h();
     libexplain_buffer_errno_fubar_c();
     libexplain_buffer_errno_fubar_h();
-    libexplain_errno_fubar_c();
     libexplain_fubar_c();
     libexplain_fubar_h(declaration);
-    libexplain_fubar_on_error_c(declaration);
     libexplain_fubar_or_die_c(declaration);
-    libexplain_message_errno_fubar_c();
-    libexplain_message_fubar_c();
     man_man3_explain_fubar_3();
     man_man3_explain_fubar_or_die_3(declaration);
     test_fubar_main_c();
