@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,6 +18,7 @@
  */
 
 #include <libexplain/ac/ctype.h>
+#include <libexplain/ac/stdio.h>
 #include <libexplain/ac/stdlib.h>
 #include <libexplain/ac/string.h>
 #include <libexplain/ac/regex.h>
@@ -27,13 +28,13 @@
 #include <libexplain/fopen.h>
 #include <libexplain/malloc.h>
 #include <libexplain/sizeof.h>
+#include <libexplain/string_list.h>
 
 #include <codegen/aegis.h>
 #include <codegen/catalogue.h>
 #include <codegen/elastic_buffer.h>
 #include <codegen/header.h>
 #include <codegen/ioctl_scan.h>
-#include <codegen/string_list.h>
 #include <codegen/wrapper.h>
 
 
@@ -99,7 +100,7 @@ mangle_include_file_name(const char *txt)
     op = result;
     while (ip < end)
     {
-        unsigned char c;
+        unsigned char   c;
 
         c = *ip++;
         if (isupper(c))
@@ -122,8 +123,8 @@ ioctl_scan_include(const char *pathname)
     regex_t         define_hex;
     FILE            *ofp;
     char            ofn[1000];
-    string_list_t   iocg;
-    string_list_t   iocs;
+    explain_string_list_t iocg;
+    explain_string_list_t iocs;
     char            *mangled;
     size_t          j;
 
@@ -143,8 +144,8 @@ ioctl_scan_include(const char *pathname)
     gpl_header(ofp, "# ");
     fprintf(ofp, "Include: %s\n", p);
 
-    string_list_constructor(&iocg);
-    string_list_constructor(&iocs);
+    explain_string_list_constructor(&iocg);
+    explain_string_list_constructor(&iocs);
 
     regcomp_or_die
     (
@@ -184,21 +185,29 @@ ioctl_scan_include(const char *pathname)
             len2 = match[2].rm_eo - match[2].rm_so;
             str2 = line + match[2].rm_so;
             if (len2 > 6 && 0 == memcmp(str2, "_IORW(", 6))
-                string_list_append_n(&iocs, str, len);
+                explain_string_list_append_n(&iocs, str, len);
             else if (len2 > 5 && 0 == memcmp(str2, "_IOR(", 5))
-                string_list_append_n(&iocg, str, len);
+                explain_string_list_append_n(&iocg, str, len);
             else if (len2 > 5 && 0 == memcmp(str2, "_IOW(", 5))
-                string_list_append_n(&iocs, str, len);
+                explain_string_list_append_n(&iocs, str, len);
             else if (strnstr(str, "IOCS", len))
-                string_list_append_n(&iocs, str, len);
+                explain_string_list_append_n(&iocs, str, len);
             else if (strnstr(str, "IOCG", len))
-                string_list_append_n(&iocg, str, len);
+                explain_string_list_append_n(&iocg, str, len);
             else if (strnstr(str, "SET", len))
-                string_list_append_n(&iocs, str, len);
+                explain_string_list_append_n(&iocs, str, len);
             else if (strnstr(str, "GET", len))
-                string_list_append_n(&iocg, str, len);
+                explain_string_list_append_n(&iocg, str, len);
+            else if (memcmp(str, "PIO", 3))
+                explain_string_list_append_n(&iocs, str, len);
+            else if (memcmp(str, "GIO", 3))
+                explain_string_list_append_n(&iocg, str, len);
+            else if (memcmp(str, "KDS", 3))
+                explain_string_list_append_n(&iocs, str, len);
+            else if (memcmp(str, "KDG", 3))
+                explain_string_list_append_n(&iocg, str, len);
             else
-                string_list_append_n(&iocs, str, len);
+                explain_string_list_append_n(&iocs, str, len);
         }
     }
     regfree(&define_io);
@@ -209,19 +218,19 @@ ioctl_scan_include(const char *pathname)
         "state or media state. These are safe to probe, and will not cause "
         "probems or damage.");
     fprintf(ofp, "Get:\n");
-    string_list_sort(&iocg);
+    explain_string_list_sort(&iocg);
     for (j = 0; j < iocg.length; ++j)
         fprintf(ofp, " %s\n", iocg.string[j]);
 
     fprintf(ofp, "#\n");
     wrapper(ofp, "# ", "These are requests that alter the system state.");
     fprintf(ofp, "Set:\n");
-    string_list_sort(&iocs);
+    explain_string_list_sort(&iocs);
     for (j = 0; j < iocs.length; ++j)
         fprintf(ofp, " %s\n", iocs.string[j]);
 
-    string_list_destructor(&iocg);
-    string_list_destructor(&iocs);
+    explain_string_list_destructor(&iocg);
+    explain_string_list_destructor(&iocs);
 
     explain_fclose_or_die(fp);
     explain_fclose_or_die(ofp);
@@ -282,7 +291,8 @@ ioctl_scan_generate(const char *pathname)
     char            ofn[1000];
     const char      *getters_str;
     const char      *setters_str;
-    string_list_t   getters_list;
+    explain_string_list_t getters_list;
+    explain_string_list_t ioctl_list;
     FILE            *ofp;
     size_t          j;
     elastic_buffer_t buf;
@@ -299,9 +309,11 @@ ioctl_scan_generate(const char *pathname)
     elastic_buffer_constructor(&buf);
 
     getters_str = catalogue_get(cat, "get");
-    string_list_constructor(&getters_list);
-    split(&getters_list, getters_str);
-    string_list_sort(&getters_list);
+    explain_string_list_constructor(&getters_list);
+    explain_string_list_split(&getters_list, getters_str);
+    explain_string_list_constructor(&ioctl_list);
+    explain_string_list_split(&ioctl_list, getters_str);
+    explain_string_list_sort(&getters_list);
 
     snprintf(ofn, sizeof(ofn), "ioctl-scan/scan/%s.c", func);
     aegis_new_file(ofn);
@@ -315,30 +327,6 @@ ioctl_scan_generate(const char *pathname)
     fprintf(ofp, "#include <ioctl-scan/report.h>\n");
     fprintf(ofp, "#include <ioctl-scan/scan/%s.h>\n", func);
     fprintf(ofp, "\n");
-    for (j = 0; j < getters_list.length; ++j)
-    {
-        const char *getter = getters_list.string[j];
-        char *lc_getter = downcase(getter);
-
-        fprintf(ofp, "\n");
-        fprintf(ofp, "#ifdef %s\n", getter);
-        fprintf(ofp, "\n");
-        fprintf(ofp, "static void\n");
-        fprintf(ofp, "%s(int fildes)\n", lc_getter);
-        fprintf(ofp, "{\n");
-        fprintf(ofp, "    int             data;\n");
-        fprintf(ofp, "\n");
-        fprintf(ofp, "    if (ioctl(fildes, %s, &data) >= 0)\n", getter);
-        fprintf(ofp, "    {\n");
-        fprintf(ofp, "        report_int(\"%s\", \"%s\", data, \"units\");\n",
-            getter, lc_getter);
-        fprintf(ofp, "    }\n");
-        fprintf(ofp, "}\n");
-        fprintf(ofp, "\n");
-        fprintf(ofp, "#endif\n");
-        free(lc_getter);
-    }
-    fprintf(ofp, "\n");
     fprintf(ofp, "\n");
     fprintf(ofp, "void\n");
     fprintf(ofp, "scan_%s(int fildes)\n", func);
@@ -348,7 +336,7 @@ ioctl_scan_generate(const char *pathname)
         const char *getter = getters_list.string[j];
         char *lc_getter = downcase(getter);
         fprintf(ofp, "#ifdef %s\n", getter);
-        fprintf(ofp, "    %s(fildes);\n", lc_getter);
+        fprintf(ofp, "    report_semi_auto(fildes, %s);\n", getter);
         fprintf(ofp, "#endif\n");
         free(lc_getter);
     }
@@ -395,18 +383,20 @@ ioctl_scan_generate(const char *pathname)
     explain_fclose_or_die(ofp);
 
     /*
-     * Now we take all of the i/i controls and generate
+     * Now we take all of the ioctl requests and generate
      * libexplain/iocontrol/%s.{h,c} for each of them.
      */
     setters_str = catalogue_get(cat, "set");
-    split(&getters_list, setters_str);
-    string_list_sort(&getters_list);
+    explain_string_list_split(&ioctl_list, setters_str);
+    explain_string_list_sort(&ioctl_list);
 
-    for (j = 0; j < getters_list.length; ++j)
+    for (j = 0; j < ioctl_list.length; ++j)
     {
-        const char *name = getters_list.string[j];
-        char *lc_name = downcase(name);
+        const char      *name;
+        char            *lc_name;
 
+        name = ioctl_list.string[j];
+        lc_name = downcase(name);
         snprintf(ofn, sizeof(ofn), "libexplain/iocontrol/%s.h", lc_name);
         aegis_new_file(ofn);
         ofp = explain_fopen_or_die(ofn, "w");
@@ -462,11 +452,10 @@ ioctl_scan_generate(const char *pathname)
         fprintf(ofp, "\n");
         fprintf(ofp, "#include <libexplain/ac/%s>\n", include_file_name);
         fprintf(ofp, "\n");
+        fprintf(ofp, "#include <libexplain/buffer/%s.h>\n", lc_name);
         fprintf(ofp, "#include <libexplain/iocontrol/generic.h>\n");
         fprintf(ofp, "#include <libexplain/iocontrol/%s.h>\n", lc_name);
         fprintf(ofp, "\n");
-        fprintf(ofp, "#include <libexplain/buffer/%s.h>\n", lc_name);
-        fprintf(ofp, "\n");
 
         fprintf(ofp, "#ifdef %s\n", name);
         fprintf(ofp, "\n");
@@ -528,10 +517,11 @@ ioctl_scan_generate(const char *pathname)
         fprintf(ofp, "    %s, /* value */\n", name);
         fprintf(ofp, "    0, /* disambiguate */\n");
         fprintf(ofp, "    0, /* print_name */\n");
-        fprintf(ofp, "    print_data,\n");
-        fprintf(ofp, "    print_explanation,\n");
+        fprintf(ofp, "    0, /* print_data */\n");
+        fprintf(ofp, "    0, /* print_explanation */\n");
+        fprintf(ofp, "    0, /* print_data_returned */\n");
+        fprintf(ofp, "    sizeof(struct %s), /* data_size */\n", lc_name);
         fprintf(ofp, "    __FILE__,\n");
-        fprintf(ofp, "    print_data_returned,\n");
         fprintf(ofp, "    __LINE__,\n");
         fprintf(ofp, "};\n");
         fprintf(ofp, "\n");
@@ -547,6 +537,7 @@ ioctl_scan_generate(const char *pathname)
         fprintf(ofp, "    0, /* print_data */\n");
         fprintf(ofp, "    0, /* print_explanation */\n");
         fprintf(ofp, "    0, /* print_data_returned */\n");
+        fprintf(ofp, "    0, /* data_size */\n");
         fprintf(ofp, "    __FILE__,\n");
         fprintf(ofp, "    __LINE__,\n");
         fprintf(ofp, "};\n");
@@ -555,5 +546,28 @@ ioctl_scan_generate(const char *pathname)
         explain_fclose_or_die(ofp);
     }
 
+    snprintf(ofn, sizeof(ofn), "libexplain/iocontrol/table.c");
+    aegis_copy_file(ofn);
+    ofp = explain_fopen_or_die(ofn, "a");
+    for (j = 0; j < ioctl_list.length; ++j)
+    {
+        const char      *name;
+        char            *lc_name;
+
+        name = ioctl_list.string[j];
+        lc_name = downcase(name);
+        fprintf(ofp, "#include <libexplain/iocontrol/%s.h>\n", lc_name);
+    }
+    for (j = 0; j < ioctl_list.length; ++j)
+    {
+        const char      *name;
+        char            *lc_name;
+
+        name = ioctl_list.string[j];
+        lc_name = downcase(name);
+        fprintf(ofp, "    &explain_iocontrol_%s,\n", lc_name);
+    }
+    explain_fclose_or_die(ofp);
+
     elastic_buffer_destructor(&buf);
 }
