@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,12 @@
 #ifndef LIBEXPLAIN_AC_USTAT_H
 #define LIBEXPLAIN_AC_USTAT_H
 
-#include <libexplain/config.h>
+/**
+  * @file
+  * @brief Insulate <ustat.h> differences
+  */
+
+#include <libexplain/ac/sys/types.h>
 
 #ifdef HAVE_USTAT_H
 #include <ustat.h>
@@ -37,4 +42,8 @@ struct ustat
 
 #endif
 
+#if !HAVE_DECL_USTAT
+int ustat(dev_t dev, struct ustat *data);
+#endif
+
 #endif /* LIBEXPLAIN_AC_USTAT_H */
