@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,7 @@
 #include <libexplain/buffer/errno/close.h>
 #include <libexplain/buffer/errno/generic.h>
 #include <libexplain/buffer/fildes_to_pathname.h>
+#include <libexplain/buffer/gettext.h>
 #include <libexplain/explanation.h>
 #include <libexplain/string_buffer.h>
 
@@ -53,12 +54,6 @@ explain_buffer_errno_close_explanation(explain_string_buffer_t *sb,
 
     case EINTR:
         explain_buffer_eintr(sb, syscall_name);
-        explain_string_buffer_puts
-        (
-            sb,
-            /* FIXME: i18n */
-            "; note that the file descriptor is still open"
-        );
         break;
 
     case EIO:
@@ -69,12 +64,15 @@ explain_buffer_errno_close_explanation(explain_string_buffer_t *sb,
 #if defined(EWOULDBLOCK) && EWOULDBLOCK != EAGAIN
     case EWOULDBLOCK:
 #endif
-        explain_string_buffer_puts
+        explain_buffer_gettext
         (
             sb,
-            /* FIXME: i18n */
-            "the O_NONBLOCK flag was specified, and an "
-            "operation has yet to complete"
+            /*
+             * xgettext: This error message is used when trying to close
+             * a non-blocking file descriptor that is stillactive.
+             */
+            i18n("the O_NONBLOCK flag was specified, and an operation "
+                "has yet to complete")
         );
         break;
 
@@ -88,11 +86,15 @@ explain_buffer_errno_close_explanation(explain_string_buffer_t *sb,
      */
     if (fcntl(fildes, F_GETFL) >= 0)
     {
-        explain_string_buffer_puts
+        explain_string_buffer_puts(sb->footnotes, "; ");
+        explain_buffer_gettext
         (
-            sb,
-            /* FIXME: i18n */
-            "; note that the file descriptor is still open"
+            sb->footnotes,
+            /*
+             * xgettext:  This error message is used when a close(2)
+             * system call fails and the file descriptor remains open.
+             */
+            i18n("note that the file descriptor is still open")
         );
     }
 }
