@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
@@ -28,20 +28,31 @@
 #include <libexplain/path_is_efault.h>
 #include <libexplain/sizeof.h>
 
+#if defined(SIOCADDRT) || defined(SIOCDELRT) || defined(SIOCRTMSG)
 
 static void
 explain_buffer_rtentry_flags(explain_string_buffer_t *sb, int flags)
 {
     static const explain_parse_bits_table_t table[] =
     {
+#ifdef RTF_UP
         { "RTF_UP", RTF_UP },
+#endif
+#ifdef RTF_GATEWAY
         { "RTF_GATEWAY", RTF_GATEWAY },
+#endif
+#ifdef RTF_HOST
         { "RTF_HOST", RTF_HOST },
+#endif
 #ifdef RTF_REINSTATE
         { "RTF_REINSTATE", RTF_REINSTATE },
 #endif
+#ifdef RTF_DYNAMIC
         { "RTF_DYNAMIC", RTF_DYNAMIC },
+#endif
+#ifdef RTF_MODIFIED
         { "RTF_MODIFIED", RTF_MODIFIED },
+#endif
 #ifdef RTF_MTU
         { "RTF_MTU", RTF_MTU },
 #endif
@@ -51,7 +62,9 @@ explain_buffer_rtentry_flags(explain_string_buffer_t *sb, int flags)
 #ifdef RTF_IRTT
         { "RTF_IRTT", RTF_IRTT },
 #endif
+#ifdef RTF_REJECT
         { "RTF_REJECT", RTF_REJECT },
+#endif
     };
 
     explain_parse_bits_print(sb, flags, table, SIZEOF(table));
@@ -94,3 +107,14 @@ explain_buffer_rtentry(explain_string_buffer_t *sb,
 #endif
     explain_string_buffer_puts(sb, " }");
 }
+
+#else
+
+void
+explain_buffer_rtentry(explain_string_buffer_t *sb,
+    const struct rtentry *data)
+{
+    explain_buffer_pointer(sb, data);
+}
+
+#endif
