@@ -20,6 +20,7 @@
 #include <libexplain/ac/linux/fd.h>
 
 #include <libexplain/iocontrol/fdflush.h>
+#include <libexplain/iocontrol/generic.h>
 
 
 #ifdef FDFLUSH
@@ -30,9 +31,10 @@ const explain_iocontrol_t explain_iocontrol_fdflush =
     FDFLUSH, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data, */
+    explain_iocontrol_generic_print_data_ignored, /* print_data, */
     0, /* print_explanation */
     0, /* print_data_returned */
+    NOT_A_POINTER, /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +50,7 @@ const explain_iocontrol_t explain_iocontrol_fdflush =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
