@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,21 +19,11 @@
 
 #include <libexplain/ac/sys/ioctl.h>
 
-#include <libexplain/buffer/int.h>
 #include <libexplain/iocontrol/fionbio.h>
+#include <libexplain/iocontrol/generic.h>
 
 
-static void
-print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
-    int errnum, int fildes, int request, const void *data)
-{
-    (void)p;
-    (void)errnum;
-    (void)fildes;
-    (void)request;
-    explain_buffer_int_star(sb, data);
-}
-
+#ifdef FIONBIO
 
 const explain_iocontrol_t explain_iocontrol_fionbio =
 {
@@ -41,9 +31,28 @@ const explain_iocontrol_t explain_iocontrol_fionbio =
     FIONBIO, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    print_data,
+    explain_iocontrol_generic_print_data_int_star, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(int), /* data_size */
     __FILE__,
     __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_fionbio =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    0, /* data_size */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
