@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,22 +18,11 @@
  */
 
 #include <libexplain/ac/sys/filio.h>
+#include <libexplain/ac/sys/ioctl.h>
 #include <libexplain/ac/sys/socket.h>
 
-#include <libexplain/buffer/int.h>
 #include <libexplain/iocontrol/fiosetown.h>
-
-
-static void
-print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
-    int errnum, int fildes, int request, const void *data)
-{
-    (void)p;
-    (void)errnum;
-    (void)fildes;
-    (void)request;
-    explain_buffer_int_star(sb, data);
-}
+#include <libexplain/iocontrol/generic.h>
 
 
 const explain_iocontrol_t explain_iocontrol_fiosetown =
@@ -42,9 +31,10 @@ const explain_iocontrol_t explain_iocontrol_fiosetown =
     FIOSETOWN, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    print_data,
+    explain_iocontrol_generic_print_data_int_star, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(int), /* data_size */
     __FILE__,
     __LINE__,
 };
