@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,6 +19,7 @@
 
 #include <libexplain/ac/ctype.h>
 #include <libexplain/ac/errno.h>
+#include <libexplain/ac/stdint.h>
 #include <libexplain/ac/stdlib.h>
 #include <libexplain/ac/sys/ioctl.h>
 
@@ -33,13 +34,21 @@
 #include <libexplain/buffer/erofs.h>
 #include <libexplain/buffer/errno/generic.h>
 #include <libexplain/buffer/gettext.h>
+#include <libexplain/buffer/int.h>
+#include <libexplain/buffer/int8.h>
+#include <libexplain/buffer/int64_t.h>
 #include <libexplain/buffer/is_the_null_pointer.h>
+#include <libexplain/buffer/long.h>
+#include <libexplain/buffer/pointer.h>
+#include <libexplain/buffer/short.h>
 #include <libexplain/iocontrol/generic.h>
 #include <libexplain/parse_bits.h>
 #include <libexplain/sizeof.h>
 #include <libexplain/string_buffer.h>
 
 
+#if defined(_IOC_DIR) || defined(IOC_DIRMASK)
+
 static const explain_parse_bits_table_t ioc_dir_table[] =
 {
 #ifdef _IOC_NONE
@@ -190,6 +199,8 @@ iorw(explain_string_buffer_t *sb, int type, int nr, int size)
     explain_string_buffer_putc(sb, ')');
 }
 
+#endif
+
 
 static void
 print_name(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
@@ -223,6 +234,13 @@ print_name(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
         return;
     }
 #endif
+    if (request == 0)
+    {
+        /* special case for zero */
+        explain_string_buffer_putc(sb, '0');
+        return;
+    }
+#if defined(_IOC_DIR) || defined(IOC_DIRMASK)
     {
         int             ioc_dir;
         int             ioc_type;
@@ -261,7 +279,7 @@ print_name(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
                 ioc(sb, ioc_dir, ioc_type, ioc_nr, ioc_size);
             else
                 io(sb, ioc_type, ioc_nr);
-            break;
+            return;
 
 #ifdef _IOC_READ
         case _IOC_READ:
@@ -269,10 +287,11 @@ print_name(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
 #ifdef IOC_OUT
         case IOC_OUT:
 #endif
-            if (ioc_size == 0)
-                ioc(sb, ioc_dir, ioc_type, ioc_nr, ioc_size);
-            else
+            if (ioc_size != 0)
+            {
                 ior(sb, ioc_type, ioc_nr, ioc_size);
+                return;
+            }
             break;
 
 #ifdef _IOC_WRITE
@@ -281,10 +300,11 @@ print_name(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
 #ifdef IOC_IN
         case IOC_IN:
 #endif
-            if (ioc_size == 0)
-                ioc(sb, ioc_dir, ioc_type, ioc_nr, ioc_size);
-            else
+            if (ioc_size != 0)
+            {
                 iow(sb, ioc_type, ioc_nr, ioc_size);
+                return;
+            }
             break;
 
 #ifdef IOC_INOUT
@@ -293,17 +313,24 @@ print_name(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
 #if defined(_IOC_READ) && defined(_IOC_WRITE)
         case _IOC_READ | _IOC_WRITE:
 #endif
-            if (ioc_size == 0)
-                ioc(sb, ioc_dir, ioc_type, ioc_nr, ioc_size);
-            else
+            if (ioc_size != 0)
+            {
                 iorw(sb, ioc_type, ioc_nr, ioc_size);
+                return;
+            }
             break;
 
         default:
-            ioc(sb, ioc_dir, ioc_type, ioc_nr, ioc_size);
+            if (ioc_size != 0)
+            {
+                ioc(sb, ioc_dir, ioc_type, ioc_nr, ioc_size);
+                return;
+            }
             break;
         }
     }
+#endif
+    explain_string_buffer_printf(sb, "0x%X", request);
 }
 
 
@@ -413,15 +440,232 @@ explain_iocontrol_generic_print_explanation(const explain_iocontrol_t *p,
 }
 
 
+/*
+ * The third argument is an untyped pointer to memory.  It's
+ * traditionally char *argp (from the days before "void *" was valid C).
+ * So for undefined ioctl requets, we will interpret and print a generic
+ * pointer for the third argument (print_data).
+ */
 const explain_iocontrol_t explain_iocontrol_generic =
 {
     0, /* name */
     0, /* value */
     0, /* disambiguate */
     print_name,
-    0, /* print data */
+    explain_iocontrol_generic_print_data_pointer, /* print data */
     explain_iocontrol_generic_print_explanation,
     0, /* print_data_returned */
+    NOT_A_POINTER, /* data_size */
     __FILE__,
     __LINE__,
 };
+
+
+void
+explain_iocontrol_generic_print_data_int(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_int(sb, (intptr_t)data);
+}
+
+
+void
+explain_iocontrol_generic_print_data_uint(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_uint(sb, (intptr_t)data);
+}
+
+
+void
+explain_iocontrol_generic_print_data_int_star(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_int_star(sb, data);
+}
+
+
+void
+explain_iocontrol_generic_print_data_uint_star(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_uint_star(sb, data);
+}
+
+
+void
+explain_iocontrol_generic_print_data_long(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_long(sb, (intptr_t)data);
+}
+
+
+void
+explain_iocontrol_generic_print_data_ulong(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_ulong(sb, (intptr_t)data);
+}
+
+
+void
+explain_iocontrol_generic_print_data_long_star(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_long_star(sb, data);
+}
+
+
+void
+explain_iocontrol_generic_print_data_ulong_star(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_ulong_star(sb, data);
+}
+
+
+void
+explain_iocontrol_generic_print_data_pointer(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_pointer(sb, data);
+}
+
+
+void
+explain_iocontrol_generic_print_data_int64_star(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_int64_array(sb, data, 1);
+}
+
+
+void
+explain_iocontrol_generic_print_data_uint64_star(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_uint64_array(sb, data, 1);
+}
+
+
+void
+explain_iocontrol_generic_print_data_ignored(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_pointer(sb, data);
+    if (data)
+        explain_string_buffer_puts(sb, " ignored");
+}
+
+
+void
+explain_iocontrol_generic_print_data_short_star(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_short_star(sb, data, 1);
+}
+
+
+void
+explain_iocontrol_generic_print_data_ushort_star(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_ushort_star(sb, data, 1);
+}
+
+
+void
+explain_iocontrol_generic_print_data_int8_star(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_int8_star(sb, data, 1);
+}
+
+
+void
+explain_iocontrol_generic_print_data_uint8_star(const explain_iocontrol_t *p,
+    explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_uint8_star(sb, data, 1);
+}
