@@ -19,20 +19,36 @@
 
 #include <libexplain/ac/linux/kd.h>
 
+#include <libexplain/buffer/int8.h>
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/gio_cmap.h>
 
 
 #ifdef GIO_CMAP
 
+static void
+print_data_returned(const explain_iocontrol_t *p,
+    struct explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_uint8_star(sb, data, 3 * 16);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_gio_cmap =
 {
     "GIO_CMAP", /* name */
     GIO_CMAP, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    3 * 16, /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_gio_cmap =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
