@@ -19,20 +19,36 @@
 
 #include <libexplain/ac/linux/kd.h>
 
+#include <libexplain/buffer/char_data.h>
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/gio_font.h>
 
 
 #ifdef GIO_FONT
 
+static void
+print_data_returned(const explain_iocontrol_t *p,
+    struct explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_char_data(sb, data, 1 * 32 * 256);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_gio_font =
 {
     "GIO_FONT", /* name */
     GIO_FONT, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    1 * 32 * 256, /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_gio_font =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
