@@ -45,7 +45,8 @@ const explain_iocontrol_t explain_iocontrol_gio_fontx =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data, /* print_data_returned */
+    sizeof(struct consolefontdesc), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -61,6 +62,7 @@ const explain_iocontrol_t explain_iocontrol_gio_fontx =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
