@@ -19,20 +19,36 @@
 
 #include <libexplain/ac/linux/kd.h>
 
+#include <libexplain/buffer/unimapdesc.h>
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/gio_unimap.h>
 
 
 #ifdef GIO_UNIMAP
 
+static void
+print_data_returned(const explain_iocontrol_t *p,
+    struct explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_unimapdesc(sb, data, 1);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_gio_unimap =
 {
     "GIO_UNIMAP", /* name */
     GIO_UNIMAP, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct unimapdesc), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_gio_unimap =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
