@@ -18,35 +18,23 @@
  */
 
 #include <libexplain/ac/linux/kd.h>
-#include <libexplain/ac/stdint.h>
 
-#include <libexplain/buffer/long.h>
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/kddelio.h>
 
 
 #ifdef HAVE_LINUX_KD_H
 
-static void
-print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
-    int errnum, int fildes, int request, const void *data)
-{
-    (void)p;
-    (void)errnum;
-    (void)fildes;
-    (void)request;
-    explain_buffer_long(sb, (intptr_t)data);
-}
-
-
 const explain_iocontrol_t explain_iocontrol_kddelio =
 {
     "KDDELIO", /* name */
     KDDELIO, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    print_data,
+    explain_iocontrol_generic_print_data_long, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    NOT_A_POINTER, /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +50,7 @@ const explain_iocontrol_t explain_iocontrol_kddelio =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
