@@ -20,6 +20,7 @@
 #include <libexplain/ac/linux/kd.h>
 
 #include <libexplain/iocontrol/kdgetled.h>
+#include <libexplain/iocontrol/generic.h>
 
 
 #ifdef KDGETLED
@@ -30,9 +31,10 @@ const explain_iocontrol_t explain_iocontrol_kdgetled =
     KDGETLED, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    explain_iocontrol_generic_print_data_int8_star, /* print_data_returned */
+    sizeof(char), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +50,7 @@ const explain_iocontrol_t explain_iocontrol_kdgetled =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
