@@ -37,6 +37,18 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
 }
 
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_kbsentry(sb, data, 1);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_kdgkbsent =
 {
     "KDGKBSENT", /* name */
@@ -45,7 +57,8 @@ const explain_iocontrol_t explain_iocontrol_kdgkbsent =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct kbsentry), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -61,6 +74,7 @@ const explain_iocontrol_t explain_iocontrol_kdgkbsent =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
