@@ -20,19 +20,25 @@
 #include <libexplain/ac/linux/kd.h>
 
 #include <libexplain/iocontrol/kdmapdisp.h>
+#include <libexplain/iocontrol/generic.h>
 
 
 #ifdef KDMAPDISP
 
+/*
+ * FIXME: not implemented in Linux kernel.
+ * need to find working exmaple to fill this out
+ */
 const explain_iocontrol_t explain_iocontrol_kdmapdisp =
 {
     "KDMAPDISP", /* name */
     KDMAPDISP, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_ignored, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    NOT_A_POINTER, /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +54,7 @@ const explain_iocontrol_t explain_iocontrol_kdmapdisp =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
