@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,36 +17,25 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/stdint.h> /* order matters for Jaunty */
 #include <libexplain/ac/linux/kd.h>
-#include <libexplain/ac/stdint.h>
 
-#include <libexplain/buffer/long.h>
 #include <libexplain/iocontrol/kdsetled.h>
+#include <libexplain/iocontrol/generic.h>
 
 
 #ifdef HAVE_LINUX_KD_H
 
-static void
-print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
-    int errnum, int fildes, int request, const void *data)
-{
-    (void)p;
-    (void)errnum;
-    (void)fildes;
-    (void)request;
-    explain_buffer_long(sb, (intptr_t)data);
-}
-
-
 const explain_iocontrol_t explain_iocontrol_kdsetled =
 {
     "KDSETLED", /* name */
     KDSETLED, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    print_data,
+    explain_iocontrol_generic_print_data_uint, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    NOT_A_POINTER, /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +51,7 @@ const explain_iocontrol_t explain_iocontrol_kdsetled =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
