@@ -19,33 +19,22 @@
 
 #include <libexplain/ac/linux/kd.h>
 
-#include <libexplain/buffer/int.h>
 #include <libexplain/iocontrol/kdsigaccept.h>
+#include <libexplain/iocontrol/generic.h>
 
 
 #ifdef HAVE_LINUX_KD_H
 
-static void
-print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
-    int errnum, int fildes, int request, const void *data)
-{
-    (void)p;
-    (void)errnum;
-    (void)fildes;
-    (void)request;
-    explain_buffer_int(sb, (long)data);
-}
-
-
 const explain_iocontrol_t explain_iocontrol_kdsigaccept =
 {
     "KDSIGACCEPT", /* name */
     KDSIGACCEPT, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    print_data,
+    explain_iocontrol_generic_print_data_int, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    NOT_A_POINTER, /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -61,6 +50,7 @@ const explain_iocontrol_t explain_iocontrol_kdsigaccept =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
