@@ -46,6 +46,7 @@ const explain_iocontrol_t explain_iocontrol_kdskbdiacruc =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct kbdiacrsuc), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -61,6 +62,7 @@ const explain_iocontrol_t explain_iocontrol_kdskbdiacruc =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
