@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,6 +17,7 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/stdint.h> /* order matters for Jaunty */
 #include <libexplain/ac/linux/kd.h>
 
 #include <libexplain/iocontrol/kdskbmode.h>
@@ -50,7 +51,7 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
     (void)errnum;
     (void)fildes;
     (void)request;
-    explain_buffer_kdskbmode(sb, (long)data);
+    explain_buffer_kdskbmode(sb, (intptr_t)data);
 }
 
 
@@ -63,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_kdskbmode =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    NOT_A_POINTER, /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -78,6 +80,7 @@ const explain_iocontrol_t explain_iocontrol_kdskbmode =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
