@@ -19,20 +19,36 @@
 
 #include <libexplain/ac/sys/mtio.h>
 
+#include <libexplain/buffer/mtpos.h>
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/mtiocpos.h>
 
 
 #ifdef MTIOCPOS
 
+static void
+print_data_returned(const explain_iocontrol_t *p,
+    struct explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_mtpos(sb, data);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_mtiocpos =
 {
     "MTIOCPOS", /* name */
     MTIOCPOS, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct mtpos), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_mtiocpos =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
