@@ -47,6 +47,7 @@ const explain_iocontrol_t explain_iocontrol_mtioctop =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct mtop), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +63,7 @@ const explain_iocontrol_t explain_iocontrol_mtioctop =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
