@@ -36,7 +36,7 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
     (void)errnum;
     (void)fildes;
     (void)request;
-    explain_buffer_char_data(sb, data, 8192);
+    explain_buffer_char_data(sb, data, 1 * 32 * 256);
 }
 
 
@@ -49,6 +49,7 @@ const explain_iocontrol_t explain_iocontrol_pio_font =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    1 * 32 * 256, /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -64,6 +65,7 @@ const explain_iocontrol_t explain_iocontrol_pio_font =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
