@@ -19,7 +19,7 @@
 
 #include <libexplain/ac/linux/kd.h>
 
-#include <libexplain/buffer/char_data.h>
+#include <libexplain/buffer/short.h>
 #include <libexplain/iocontrol/pio_uniscrnmap.h>
 
 
@@ -33,7 +33,7 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
     (void)errnum;
     (void)fildes;
     (void)request;
-    explain_buffer_char_data(sb, data, E_TABSZ);
+    explain_buffer_short_star(sb, data, E_TABSZ);
 }
 
 
@@ -46,6 +46,7 @@ const explain_iocontrol_t explain_iocontrol_pio_uniscrnmap =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(short[E_TABSZ]), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -61,6 +62,7 @@ const explain_iocontrol_t explain_iocontrol_pio_uniscrnmap =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
