@@ -20,6 +20,7 @@
 #include <libexplain/ac/sys/socket.h>
 #include <libexplain/ac/sys/sockio.h>
 
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/siocatmark.h>
 
 
@@ -29,9 +30,10 @@ const explain_iocontrol_t explain_iocontrol_siocatmark =
     SIOCATMARK, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_ignored, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    NOT_A_POINTER, /* data_size */
     __FILE__,
     __LINE__,
 };
