@@ -48,6 +48,7 @@ const explain_iocontrol_t explain_iocontrol_siocbrdelbr =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(char[IFNAMSIZ]), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -63,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_siocbrdelbr =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
