@@ -49,6 +49,7 @@ const explain_iocontrol_t explain_iocontrol_siocdarp =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct arpreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -64,6 +65,7 @@ const explain_iocontrol_t explain_iocontrol_siocdarp =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
