@@ -17,6 +17,7 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/linux/if_frad.h>
 #include <libexplain/ac/linux/sockios.h>
 #include <libexplain/ac/sys/sockio.h>
 
@@ -47,6 +48,7 @@ const explain_iocontrol_t explain_iocontrol_siocdeldlci =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct dlci_add), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_siocdeldlci =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
