@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,8 +17,10 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/sys/ioctl.h>
+#include <libexplain/ac/stdint.h> /* order matters for Jaunty */
+#include <libexplain/ac/linux/ipv6.h>
 #include <libexplain/ac/net/if.h>
+#include <libexplain/ac/sys/ioctl.h>
 
 #include <libexplain/buffer/in6_ifreq.h>
 #include <libexplain/iocontrol/siocdifaddr.h>
@@ -47,6 +49,7 @@ const explain_iocontrol_t explain_iocontrol_siocdifaddr =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct in6_ifreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +65,7 @@ const explain_iocontrol_t explain_iocontrol_siocdifaddr =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
