@@ -18,6 +18,7 @@
  */
 
 #include <libexplain/ac/linux/sockios.h>
+#include <libexplain/ac/net/if.h>
 #include <libexplain/ac/sys/sockio.h>
 
 #include <libexplain/buffer/siocethtool.h>
@@ -47,6 +48,7 @@ const explain_iocontrol_t explain_iocontrol_siocethtool =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct ifreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_siocethtool =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
