@@ -21,6 +21,7 @@
 #include <libexplain/ac/net/if.h>
 
 #include <libexplain/buffer/ifreq_name.h>
+#include <libexplain/buffer/ifreq_brdaddr.h>
 #include <libexplain/iocontrol/siocgifbrdaddr.h>
 
 
@@ -38,6 +39,18 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
 }
 
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_ifreq_brdaddr(sb, data);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_siocgifbrdaddr =
 {
     "SIOCGIFBRDADDR", /* name */
@@ -46,7 +59,8 @@ const explain_iocontrol_t explain_iocontrol_siocgifbrdaddr =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct ifreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +76,7 @@ const explain_iocontrol_t explain_iocontrol_siocgifbrdaddr =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
