@@ -46,7 +46,8 @@ const explain_iocontrol_t explain_iocontrol_siocgifconf =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data, /* print_data_returned */
+    sizeof(struct ifconf), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +63,7 @@ const explain_iocontrol_t explain_iocontrol_siocgifconf =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
