@@ -21,6 +21,7 @@
 #include <libexplain/ac/sys/sockio.h>
 #include <libexplain/ac/net/if.h>
 
+#include <libexplain/buffer/ifreq_flags.h>
 #include <libexplain/buffer/ifreq_name.h>
 #include <libexplain/iocontrol/siocgifflags.h>
 
@@ -39,6 +40,18 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
 }
 
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_ifreq_flags(sb, data);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_siocgifflags =
 {
     "SIOCGIFFLAGS", /* name */
@@ -47,7 +60,8 @@ const explain_iocontrol_t explain_iocontrol_siocgifflags =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct ifreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -63,6 +77,7 @@ const explain_iocontrol_t explain_iocontrol_siocgifflags =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
