@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 #include <libexplain/ac/sys/sockio.h>
 #include <libexplain/ac/net/if.h>
 
+#include <libexplain/buffer/ifreq_ifindex.h>
 #include <libexplain/buffer/ifreq_name.h>
 #include <libexplain/iocontrol/siocgifindex.h>
 
@@ -39,15 +40,28 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
 }
 
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_ifreq_ifindex(sb, data);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_siocgifindex =
 {
     "SIOCGIFINDEX", /* name */
     SIOCGIFINDEX, /* value */
-    0, /* disambiguate */
+    explain_iocontrol_disambiguate_true, /* has "typo" synonym */
     0, /* print_name */
     print_data,
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct ifreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -63,6 +77,7 @@ const explain_iocontrol_t explain_iocontrol_siocgifindex =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
