@@ -17,9 +17,11 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/net/if.h>
 #include <libexplain/ac/sys/ioctl.h>
 
 #include <libexplain/buffer/ifreq_name.h>
+#include <libexplain/buffer/ifreq_flags.h>
 #include <libexplain/iocontrol/siocgifpflags.h>
 
 
@@ -37,6 +39,18 @@ print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
 }
 
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_ifreq_flags(sb, data);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_siocgifpflags =
 {
     "SIOCGIFPFLAGS", /* name */
@@ -45,7 +59,8 @@ const explain_iocontrol_t explain_iocontrol_siocgifpflags =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct ifreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -61,6 +76,7 @@ const explain_iocontrol_t explain_iocontrol_siocgifpflags =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
