@@ -17,6 +17,7 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/linux/mii.h>
 #include <libexplain/ac/linux/sockios.h>
 #include <libexplain/ac/sys/sockio.h>
 
@@ -46,7 +47,8 @@ const explain_iocontrol_t explain_iocontrol_siocgmiiphy =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data, /* print_data_returned */
+    sizeof(struct mii_ioctl_data), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_siocgmiiphy =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
