@@ -18,6 +18,7 @@
  */
 
 #include <libexplain/ac/linux/sockios.h>
+#include <libexplain/ac/net/if.h>
 #include <libexplain/ac/sys/sockio.h>
 
 #include <libexplain/buffer/ifreq_mii.h>
@@ -46,7 +47,8 @@ const explain_iocontrol_t explain_iocontrol_siocgmiireg =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data, /* print_data_returned */
+    sizeof(struct ifreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_siocgmiireg =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
