@@ -18,6 +18,7 @@
  */
 
 #include <libexplain/ac/sys/ioctl.h>
+#include <libexplain/ac/net/if_arp.h>
 
 #include <libexplain/buffer/arpreq.h>
 #include <libexplain/iocontrol/siocgrarp.h>
@@ -45,7 +46,8 @@ const explain_iocontrol_t explain_iocontrol_siocgrarp =
     0, /* print_name */
     print_data,
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data, /* print_data_returned */
+    sizeof(struct arpreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -61,6 +63,7 @@ const explain_iocontrol_t explain_iocontrol_siocgrarp =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
