@@ -17,22 +17,39 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/net/if.h>
 #include <libexplain/ac/sys/ioctl.h>
 
+#include <libexplain/buffer/ifreq_metric.h>
 #include <libexplain/iocontrol/siocsifmem.h>
 
 
 #ifdef SIOCSIFMEM
 
+static void
+print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_ifreq_metric(sb, data);
+}
+
+
+/* Set the per device memory buffer space. */
+
 const explain_iocontrol_t explain_iocontrol_siocsifmem =
 {
     "SIOCSIFMEM", /* name */
     SIOCSIFMEM, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct ifreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +65,7 @@ const explain_iocontrol_t explain_iocontrol_siocsifmem =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
