@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,8 +20,22 @@
 #include <libexplain/ac/sys/ioctl.h>
 #include <libexplain/ac/net/if.h>
 
+#include <libexplain/buffer/ifreq_metric.h>
 #include <libexplain/iocontrol/siocsifmetric.h>
 
+#ifdef SIOCSIFMETRIC
+
+static void
+print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_ifreq_metric(sb, data);
+}
+
 
 const explain_iocontrol_t explain_iocontrol_siocsifmetric =
 {
@@ -29,9 +43,28 @@ const explain_iocontrol_t explain_iocontrol_siocsifmetric =
     SIOCSIFMETRIC, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct ifreq), /* data_size */
     __FILE__,
     __LINE__,
 };
+
+#else
+
+const explain_iocontrol_t explain_iocontrol_siocsifmetric =
+{
+    0, /* name */
+    0, /* value */
+    0, /* disambiguate */
+    0, /* print_name */
+    0, /* print_data */
+    0, /* print_explanation */
+    0, /* print_data_returned */
+    0, /* data_size */
+    __FILE__,
+    __LINE__,
+};
+
+#endif
