@@ -17,22 +17,37 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/net/if_arp.h>
 #include <libexplain/ac/sys/ioctl.h>
 
+#include <libexplain/buffer/arpreq.h>
 #include <libexplain/iocontrol/siocsrarp.h>
 
 
 #ifdef SIOCSRARP
 
+static void
+print_data(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_arpreq(sb, data);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_siocsrarp =
 {
     "SIOCSRARP", /* name */
     SIOCSRARP, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct arpreq), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +63,7 @@ const explain_iocontrol_t explain_iocontrol_siocsrarp =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
