@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -107,6 +107,14 @@
 #include <libexplain/iocontrol/dvd_auth.h>
 #include <libexplain/iocontrol/dvd_read_struct.h>
 #include <libexplain/iocontrol/dvd_write_struct.h>
+#include <libexplain/iocontrol/eql_emancipate.h>
+#include <libexplain/iocontrol/eql_enslave.h>
+#include <libexplain/iocontrol/eql_getmastrcfg.h>
+#include <libexplain/iocontrol/eql_getslavecfg.h>
+#include <libexplain/iocontrol/eql_setmastrcfg.h>
+#include <libexplain/iocontrol/eql_setslavecfg.h>
+#include <libexplain/iocontrol/ext2_ioc_getrsvsz.h>
+#include <libexplain/iocontrol/ext2_ioc_setrsvsz.h>
 #include <libexplain/iocontrol/fdclrprm.h>
 #include <libexplain/iocontrol/fddefmediaprm.h>
 #include <libexplain/iocontrol/fddefprm.h>
@@ -228,6 +236,19 @@
 #include <libexplain/iocontrol/kdskbsent.h>
 #include <libexplain/iocontrol/kdunmapdisp.h>
 #include <libexplain/iocontrol/kiocsound.h>
+#include <libexplain/iocontrol/lpabort.h>
+#include <libexplain/iocontrol/lpabortopen.h>
+#include <libexplain/iocontrol/lpcareful.h>
+#include <libexplain/iocontrol/lpchar.h>
+#include <libexplain/iocontrol/lpgetflags.h>
+#include <libexplain/iocontrol/lpgetirq.h>
+#include <libexplain/iocontrol/lpgetstats.h>
+#include <libexplain/iocontrol/lpgetstatus.h>
+#include <libexplain/iocontrol/lpreset.h>
+#include <libexplain/iocontrol/lpsetirq.h>
+#include <libexplain/iocontrol/lpsettimeout.h>
+#include <libexplain/iocontrol/lptime.h>
+#include <libexplain/iocontrol/lpwait.h>
 #include <libexplain/iocontrol/mtiocget.h>
 #include <libexplain/iocontrol/mtiocgetconfig.h>
 #include <libexplain/iocontrol/mtiocpos.h>
@@ -241,6 +262,36 @@
 #include <libexplain/iocontrol/pio_unimap.h>
 #include <libexplain/iocontrol/pio_unimapclr.h>
 #include <libexplain/iocontrol/pio_uniscrnmap.h>
+#include <libexplain/iocontrol/pppiocattach.h>
+#include <libexplain/iocontrol/pppiocattchan.h>
+#include <libexplain/iocontrol/pppiocconnect.h>
+#include <libexplain/iocontrol/pppiocdetach.h>
+#include <libexplain/iocontrol/pppiocdisconn.h>
+#include <libexplain/iocontrol/pppiocgasyncmap.h>
+#include <libexplain/iocontrol/pppiocgchan.h>
+#include <libexplain/iocontrol/pppiocgdebug.h>
+#include <libexplain/iocontrol/pppiocgflags.h>
+#include <libexplain/iocontrol/pppiocgidle.h>
+#include <libexplain/iocontrol/pppiocgl2tpstats.h>
+#include <libexplain/iocontrol/pppiocgmru.h>
+#include <libexplain/iocontrol/pppiocgnpmode.h>
+#include <libexplain/iocontrol/pppiocgrasyncmap.h>
+#include <libexplain/iocontrol/pppiocgunit.h>
+#include <libexplain/iocontrol/pppiocgxasyncmap.h>
+#include <libexplain/iocontrol/pppiocnewunit.h>
+#include <libexplain/iocontrol/pppiocsactive.h>
+#include <libexplain/iocontrol/pppiocsasyncmap.h>
+#include <libexplain/iocontrol/pppiocscompress.h>
+#include <libexplain/iocontrol/pppiocsdebug.h>
+#include <libexplain/iocontrol/pppiocsflags.h>
+#include <libexplain/iocontrol/pppiocsmaxcid.h>
+#include <libexplain/iocontrol/pppiocsmrru.h>
+#include <libexplain/iocontrol/pppiocsmru.h>
+#include <libexplain/iocontrol/pppiocsnpmode.h>
+#include <libexplain/iocontrol/pppiocspass.h>
+#include <libexplain/iocontrol/pppiocsrasyncmap.h>
+#include <libexplain/iocontrol/pppiocsxasyncmap.h>
+#include <libexplain/iocontrol/pppiocxferunit.h>
 #include <libexplain/iocontrol/siocadddlci.h>
 #include <libexplain/iocontrol/siocaddmulti.h>
 #include <libexplain/iocontrol/siocaddrt.h>
@@ -287,6 +338,9 @@
 #include <libexplain/iocontrol/siocgmiiphy.h>
 #include <libexplain/iocontrol/siocgmiireg.h>
 #include <libexplain/iocontrol/siocgpgrp.h>
+#include <libexplain/iocontrol/siocgpppcstats.h>
+#include <libexplain/iocontrol/siocgpppstats.h>
+#include <libexplain/iocontrol/siocgpppver.h>
 #include <libexplain/iocontrol/siocgrarp.h>
 #include <libexplain/iocontrol/siocgstamp.h>
 #include <libexplain/iocontrol/siocgstampns.h>
@@ -294,6 +348,7 @@
 #include <libexplain/iocontrol/siocoutq.h>
 #include <libexplain/iocontrol/siocrtmsg.h>
 #include <libexplain/iocontrol/siocsarp.h>
+#include <libexplain/iocontrol/siocshwtstamp.h>
 #include <libexplain/iocontrol/siocsifaddr.h>
 #include <libexplain/iocontrol/siocsifbr.h>
 #include <libexplain/iocontrol/siocsifbrdaddr.h>
@@ -318,6 +373,7 @@
 #include <libexplain/iocontrol/siocspgrp.h>
 #include <libexplain/iocontrol/siocsrarp.h>
 #include <libexplain/iocontrol/siocwandev.h>
+#include <libexplain/iocontrol/siogifindex.h>
 #include <libexplain/iocontrol/table.h>
 #include <libexplain/iocontrol/tcflsh.h>
 #include <libexplain/iocontrol/tcgeta.h>
@@ -392,9 +448,22 @@
 #include <libexplain/iocontrol/tiocstop.h>
 #include <libexplain/iocontrol/tiocswinsz.h>
 #include <libexplain/iocontrol/tiocttygstruct.h>
+#include <libexplain/iocontrol/vt_activate.h>
+#include <libexplain/iocontrol/vt_disallocate.h>
+#include <libexplain/iocontrol/vt_gethifontmask.h>
+#include <libexplain/iocontrol/vt_getmode.h>
+#include <libexplain/iocontrol/vt_getstate.h>
+#include <libexplain/iocontrol/vt_lockswitch.h>
+#include <libexplain/iocontrol/vt_openqry.h>
+#include <libexplain/iocontrol/vt_reldisp.h>
+#include <libexplain/iocontrol/vt_resize.h>
+#include <libexplain/iocontrol/vt_resizex.h>
+#include <libexplain/iocontrol/vt_sendsig.h>
+#include <libexplain/iocontrol/vt_setmode.h>
+#include <libexplain/iocontrol/vt_unlockswitch.h>
+#include <libexplain/iocontrol/vt_waitactive.h>
 #include <libexplain/sizeof.h>
 
-
 /*
  * The ugly thing about ioctl(2) is that, in effect, each ioctl request is a
  * separate and unique system call.
@@ -502,6 +571,14 @@ const explain_iocontrol_t *const explain_iocontrol_table[] =
     &explain_iocontrol_dvd_auth,
     &explain_iocontrol_dvd_read_struct,
     &explain_iocontrol_dvd_write_struct,
+    &explain_iocontrol_eql_emancipate,
+    &explain_iocontrol_eql_enslave,
+    &explain_iocontrol_eql_getmastrcfg,
+    &explain_iocontrol_eql_getslavecfg,
+    &explain_iocontrol_eql_setmastrcfg,
+    &explain_iocontrol_eql_setslavecfg,
+    &explain_iocontrol_ext2_ioc_getrsvsz,
+    &explain_iocontrol_ext2_ioc_setrsvsz,
     &explain_iocontrol_fdclrprm,
     &explain_iocontrol_fddefmediaprm,
     &explain_iocontrol_fddefprm,
@@ -623,6 +700,19 @@ const explain_iocontrol_t *const explain_iocontrol_table[] =
     &explain_iocontrol_kdskbsent,
     &explain_iocontrol_kdunmapdisp,
     &explain_iocontrol_kiocsound,
+    &explain_iocontrol_lpabort,
+    &explain_iocontrol_lpabortopen,
+    &explain_iocontrol_lpcareful,
+    &explain_iocontrol_lpchar,
+    &explain_iocontrol_lpgetflags,
+    &explain_iocontrol_lpgetirq,
+    &explain_iocontrol_lpgetstats,
+    &explain_iocontrol_lpgetstatus,
+    &explain_iocontrol_lpreset,
+    &explain_iocontrol_lpsetirq,
+    &explain_iocontrol_lpsettimeout,
+    &explain_iocontrol_lptime,
+    &explain_iocontrol_lpwait,
     &explain_iocontrol_mtiocget,
     &explain_iocontrol_mtiocgetconfig,
     &explain_iocontrol_mtiocpos,
@@ -636,6 +726,36 @@ const explain_iocontrol_t *const explain_iocontrol_table[] =
     &explain_iocontrol_pio_unimap,
     &explain_iocontrol_pio_unimapclr,
     &explain_iocontrol_pio_uniscrnmap,
+    &explain_iocontrol_pppiocattach,
+    &explain_iocontrol_pppiocattchan,
+    &explain_iocontrol_pppiocconnect,
+    &explain_iocontrol_pppiocdetach,
+    &explain_iocontrol_pppiocdisconn,
+    &explain_iocontrol_pppiocgasyncmap,
+    &explain_iocontrol_pppiocgchan,
+    &explain_iocontrol_pppiocgdebug,
+    &explain_iocontrol_pppiocgflags,
+    &explain_iocontrol_pppiocgidle,
+    &explain_iocontrol_pppiocgl2tpstats,
+    &explain_iocontrol_pppiocgmru,
+    &explain_iocontrol_pppiocgnpmode,
+    &explain_iocontrol_pppiocgrasyncmap,
+    &explain_iocontrol_pppiocgunit,
+    &explain_iocontrol_pppiocgxasyncmap,
+    &explain_iocontrol_pppiocnewunit,
+    &explain_iocontrol_pppiocsactive,
+    &explain_iocontrol_pppiocsasyncmap,
+    &explain_iocontrol_pppiocscompress,
+    &explain_iocontrol_pppiocsdebug,
+    &explain_iocontrol_pppiocsflags,
+    &explain_iocontrol_pppiocsmaxcid,
+    &explain_iocontrol_pppiocsmrru,
+    &explain_iocontrol_pppiocsmru,
+    &explain_iocontrol_pppiocsnpmode,
+    &explain_iocontrol_pppiocspass,
+    &explain_iocontrol_pppiocsrasyncmap,
+    &explain_iocontrol_pppiocsxasyncmap,
+    &explain_iocontrol_pppiocxferunit,
     &explain_iocontrol_siocadddlci,
     &explain_iocontrol_siocaddmulti,
     &explain_iocontrol_siocaddrt,
@@ -682,6 +802,9 @@ const explain_iocontrol_t *const explain_iocontrol_table[] =
     &explain_iocontrol_siocgmiiphy,
     &explain_iocontrol_siocgmiireg,
     &explain_iocontrol_siocgpgrp,
+    &explain_iocontrol_siocgpppcstats,
+    &explain_iocontrol_siocgpppstats,
+    &explain_iocontrol_siocgpppver,
     &explain_iocontrol_siocgrarp,
     &explain_iocontrol_siocgstamp,
     &explain_iocontrol_siocgstampns,
@@ -689,6 +812,7 @@ const explain_iocontrol_t *const explain_iocontrol_table[] =
     &explain_iocontrol_siocoutq,
     &explain_iocontrol_siocrtmsg,
     &explain_iocontrol_siocsarp,
+    &explain_iocontrol_siocshwtstamp,
     &explain_iocontrol_siocsifaddr,
     &explain_iocontrol_siocsifbr,
     &explain_iocontrol_siocsifbrdaddr,
@@ -713,6 +837,7 @@ const explain_iocontrol_t *const explain_iocontrol_table[] =
     &explain_iocontrol_siocspgrp,
     &explain_iocontrol_siocsrarp,
     &explain_iocontrol_siocwandev,
+    &explain_iocontrol_siogifindex,
     &explain_iocontrol_tcflsh,
     &explain_iocontrol_tcgeta,
     &explain_iocontrol_tcgets,
@@ -786,6 +911,20 @@ const explain_iocontrol_t *const explain_iocontrol_table[] =
     &explain_iocontrol_tiocstop,
     &explain_iocontrol_tiocswinsz,
     &explain_iocontrol_tiocttygstruct,
+    &explain_iocontrol_vt_activate,
+    &explain_iocontrol_vt_disallocate,
+    &explain_iocontrol_vt_gethifontmask,
+    &explain_iocontrol_vt_getmode,
+    &explain_iocontrol_vt_getstate,
+    &explain_iocontrol_vt_lockswitch,
+    &explain_iocontrol_vt_openqry,
+    &explain_iocontrol_vt_reldisp,
+    &explain_iocontrol_vt_resize,
+    &explain_iocontrol_vt_resizex,
+    &explain_iocontrol_vt_sendsig,
+    &explain_iocontrol_vt_setmode,
+    &explain_iocontrol_vt_unlockswitch,
+    &explain_iocontrol_vt_waitactive,
 };
 
 const size_t explain_iocontrol_table_size = SIZEOF(explain_iocontrol_table);
