@@ -18,21 +18,36 @@
  */
 
 #include <libexplain/ac/sys/ioctl.h>
+#include <libexplain/ac/termios.h>
 
+#include <libexplain/buffer/termios.h>
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/tcgets.h>
 
 
 #ifdef TCGETS
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_termios(sb, data);
+}
+
 const explain_iocontrol_t explain_iocontrol_tcgets =
 {
     "TCGETS", /* name */
     TCGETS, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct termios), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +63,7 @@ const explain_iocontrol_t explain_iocontrol_tcgets =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
