@@ -18,20 +18,33 @@
 
 #include <libexplain/ac/linux/termios.h>
 
+#include <libexplain/buffer/termios2.h>
 #include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/tcgets2.h>
 
 #ifdef TCGETS2
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_termios2(sb, data);
+}
+
 const explain_iocontrol_t explain_iocontrol_tcgets2 =
 {
     "TCGETS2", /* name */
     TCGETS2, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct termios2), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -47,6 +60,7 @@ const explain_iocontrol_t explain_iocontrol_tcgets2 =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
