@@ -16,21 +16,35 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libexplain/ac/sys/ioctl.h>
+#include <libexplain/ac/linux/termios.h>
 
+#include <libexplain/buffer/termiox.h>
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/tcgetx.h>
 
 #ifdef TCGETX
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_termiox(sb, data);
+}
+
 const explain_iocontrol_t explain_iocontrol_tcgetx =
 {
     "TCGETX", /* name */
     TCGETX, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct termiox), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -46,6 +60,7 @@ const explain_iocontrol_t explain_iocontrol_tcgetx =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
