@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2009 Peter Miller
+ * Copyright (C) 2009, 2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 
 #include <libexplain/ac/sys/ioctl.h>
 
-#include <libexplain/buffer/termios.h>
+#include <libexplain/buffer/termio.h>
 #include <libexplain/iocontrol/tcseta.h>
 #include <libexplain/string_buffer.h>
 
@@ -47,6 +47,7 @@ const explain_iocontrol_t explain_iocontrol_tcseta =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct termio), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -62,6 +63,7 @@ const explain_iocontrol_t explain_iocontrol_tcseta =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
