@@ -18,6 +18,7 @@
  */
 
 #include <libexplain/ac/sys/ioctl.h>
+#include <libexplain/ac/termios.h>
 
 #include <libexplain/buffer/termios.h>
 #include <libexplain/iocontrol/tcsets.h>
@@ -46,6 +47,7 @@ const explain_iocontrol_t explain_iocontrol_tcsets =
     print_data,
     0, /* print_explanation */
     0, /* print_data_returned */
+    sizeof(struct termios), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -61,6 +63,7 @@ const explain_iocontrol_t explain_iocontrol_tcsets =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
