@@ -19,6 +19,7 @@
 
 #include <libexplain/ac/sys/ioctl.h>
 
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/tioccbrk.h>
 
 
@@ -30,9 +31,10 @@ const explain_iocontrol_t explain_iocontrol_tioccbrk =
     TIOCCBRK, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_ignored, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    NOT_A_POINTER, /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +50,7 @@ const explain_iocontrol_t explain_iocontrol_tioccbrk =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
