@@ -67,9 +67,10 @@ const explain_iocontrol_t explain_iocontrol_tioccons =
     TIOCCONS, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_int_star, /* print_data */
     print_explanation,
     0, /* print_data_returned */
+    sizeof(int), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -85,6 +86,7 @@ const explain_iocontrol_t explain_iocontrol_tioccons =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
