@@ -17,22 +17,39 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/linux/serial.h>
 #include <libexplain/ac/sys/ioctl.h>
 
+#include <libexplain/buffer/serial_icounter_struct.h>
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/tiocgicount.h>
 
 
 #ifdef TIOCGICOUNT
 
+static void
+print_data_returned(const explain_iocontrol_t *p,
+    struct explain_string_buffer_t *sb, int errnum, int fildes, int request,
+    const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_serial_icounter_struct(sb, data);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_tiocgicount =
 {
     "TIOCGICOUNT", /* name */
     TIOCGICOUNT, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct serial_icounter_struct), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +65,7 @@ const explain_iocontrol_t explain_iocontrol_tiocgicount =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
