@@ -17,22 +17,38 @@
  * with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <libexplain/ac/linux/serial.h>
 #include <libexplain/ac/sys/ioctl.h>
 
+#include <libexplain/buffer/serial_struct.h>
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/tiocgserial.h>
 
 
 #ifdef TIOCGSERIAL
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_serial_struct(sb, data);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_tiocgserial =
 {
     "TIOCGSERIAL", /* name */
     TIOCGSERIAL, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct serial_struct), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +64,7 @@ const explain_iocontrol_t explain_iocontrol_tiocgserial =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
