@@ -21,6 +21,7 @@
 #include <libexplain/ac/sys/ioctl.h>
 
 #include <libexplain/buffer/gettext.h>
+#include <libexplain/buffer/pid_t_star.h>
 #include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/tiocgsid.h>
 
@@ -28,9 +29,8 @@
 #ifdef TIOCGSID
 
 static void
-print_explanation(const explain_iocontrol_t *p,
-    explain_string_buffer_t *sb, int errnum, int fildes, int request,
-    const void *data)
+print_explanation(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
 {
     switch (errnum)
     {
@@ -62,15 +62,28 @@ print_explanation(const explain_iocontrol_t *p,
 }
 
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_int_pid_star(sb, data);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_tiocgsid =
 {
     "TIOCGSID", /* name */
     TIOCGSID, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     print_explanation,
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(int), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -86,6 +99,7 @@ const explain_iocontrol_t explain_iocontrol_tiocgsid =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
