@@ -19,20 +19,35 @@
 
 #include <libexplain/ac/sys/ioctl.h>
 
+#include <libexplain/buffer/winsize.h>
+#include <libexplain/iocontrol/generic.h>
 #include <libexplain/iocontrol/tiocgwinsz.h>
 
 
 #ifdef TIOCGWINSZ
 
+static void
+print_data_returned(const explain_iocontrol_t *p, explain_string_buffer_t *sb,
+    int errnum, int fildes, int request, const void *data)
+{
+    (void)p;
+    (void)errnum;
+    (void)fildes;
+    (void)request;
+    explain_buffer_winsize(sb, data);
+}
+
+
 const explain_iocontrol_t explain_iocontrol_tiocgwinsz =
 {
     "TIOCGWINSZ", /* name */
     TIOCGWINSZ, /* value */
     0, /* disambiguate */
     0, /* print_name */
-    0, /* print_data */
+    explain_iocontrol_generic_print_data_pointer, /* print_data */
     0, /* print_explanation */
-    0, /* print_data_returned */
+    print_data_returned,
+    sizeof(struct winsize), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -48,6 +63,7 @@ const explain_iocontrol_t explain_iocontrol_tiocgwinsz =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
