@@ -84,6 +84,7 @@ const explain_iocontrol_t explain_iocontrol_tiocpkt =
     print_data,
     print_explanation,
     0, /* print_data_returned */
+    sizeof(int), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -99,6 +100,7 @@ const explain_iocontrol_t explain_iocontrol_tiocpkt =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
