@@ -145,6 +145,7 @@ const explain_iocontrol_t explain_iocontrol_tiocshayesesp =
     print_data,
     print_explanation,
     0, /* print_data_returned */
+    sizeof(struct hayes_esp_config), /* data_size */
     __FILE__,
     __LINE__,
 };
@@ -160,6 +161,7 @@ const explain_iocontrol_t explain_iocontrol_tiocshayesesp =
     0, /* print_data */
     0, /* print_explanation */
     0, /* print_data_returned */
+    0, /* data_size */
     __FILE__,
     __LINE__,
 };
