@@ -1,6 +1,6 @@
 /*
  * libexplain - Explain errno values returned by libc functions
- * Copyright (C) 2008, 2009 Peter Miller
+ * Copyright (C) 2008-2010 Peter Miller
  * Written by Peter Miller <pmiller@opensource.org.au>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,13 +18,16 @@
  */
 
 #include <libexplain/ac/assert.h>
+#include <libexplain/ac/fcntl.h>
+#include <libexplain/ac/limits.h> /* for PATH_MAX except Solaris */
 #include <libexplain/ac/stdio.h>
 #include <libexplain/ac/stdlib.h>
 #include <libexplain/ac/string.h>
-#include <libexplain/ac/sys/param.h>
+#include <libexplain/ac/sys/param.h> /* for PATH_MAX except Solaris */
 #include <libexplain/ac/unistd.h>
 
 #include <libexplain/lsof.h>
+#include <libexplain/name_max.h>
 #include <libexplain/program_name.h>
 
 
@@ -101,6 +104,29 @@ explain_program_name_get(void)
         return progname;
 
 #ifdef PROC_FS_USEFUL
+    {
+        int             fd;
+
+        fd = open("/proc/self/cmdline", O_RDONLY);
+        if (fd >= 0)
+        {
+            ssize_t         n;
+            char            buf[NAME_MAX + 1];
+
+            n = read(fd, buf, sizeof(buf));
+            close(fd);
+            if (n > 0)
+            {
+                char *cp = memchr(buf, '\0', n);
+                if (cp)
+                {
+                    explain_program_name_set_real(buf);
+                    if (progname[0])
+                        return progname;
+                }
+            }
+        }
+    }
     {
         int             n;
         char            buf[PATH_MAX + 1];
@@ -118,7 +144,7 @@ explain_program_name_get(void)
         char            options[40];
 
         obj.n_callback = n_callback;
-        snprintf(options, sizeof(options), "-p %d", getpid());
+        snprintf(options, sizeof(options), "-p %ld", (long)getpid());
         explain_lsof(options, &obj);
     }
 #endif
