@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # libexplain - Explain errno values returned by libc functions
-# Copyright (C) 2009 Peter Miller
+# Copyright (C) 2009, 2010 Peter Miller
 # Written by Peter Miller <pmiller@opensource.org.au>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@ test $? -eq 0 || no_result
 test_strtof penguin > test.out.2 2>&1
 test $? -eq 1 || fail
 
-sed 's|0x[0-9a-zA-Z]*|0xNNNNNNNN|' test.out.2 > test.out
+sed 's|0x[0-9a-fA-F][0-9a-zA-Z]*|0xNNNNNNNN|' test.out.2 > test.out
 test $? -eq 0 || no_result
 
 diff test.ok test.out
