@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # libexplain - Explain errno values returned by libc functions
-# Copyright (C) 2009 Peter Miller
+# Copyright (C) 2009, 2010 Peter Miller
 # Written by Peter Miller <pmiller@opensource.org.au>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -28,10 +28,18 @@ argument (EINVAL) because the options argument was incorrectly specified
 fubar
 test $? -eq 0 || no_result
 
+cat > test.ok2 << 'fubar'
+tcsetattr(fildes = 999, options = 99, data = { c_iflag = 0, c_oflag = 0,
+c_cflag = CS5, c_lflag = 0, c_cc = {} }) failed, Invalid argument (EINVAL)
+because the options argument was incorrectly specified
+fubar
+test $? -eq 0 || no_result
+
 explain -eEINVAL tcsetattr 999 99 > test.out
 test $? -eq 0 || fail
 
-diff test.ok test.out
+diff test.ok test.out > /dev/null 2> /dev/null || \
+diff test.ok2 test.out
 test $? -eq 0 || fail
 
 #
